
# Type: union_of


indicates that the domain class consists exactly of the members of the classes in the range

URI: [meta:union_of](https://w3id.org/biolink/biolinkml/meta/union_of)


## Domain and Range

[ClassDefinition](ClassDefinition.md) ->  <sub>0..*</sub> [ClassDefinition](ClassDefinition.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
